function [distances, save_counter] = load_distances(base_path)

% [distances, save_counter] = load_distances(base_path)
%
% checks the three round-robin versions of the corresponding file, and
% loads the one with the most computed distances, based on the progress
% text file.

save_counter = 0;
best_progress = -1;
best_index = -1;
robin_length = 3;

for i = 0:(robin_length-1);
    progress = read_progress(base_path, i);
    if progress > best_progress
      best_progress = progress;
      best_index = i;
  end
end

% If we did find a progress file, we are all set, we just need
% to load up that matrix.
if best_index >= 0
  distances = read_distances(base_path, best_index);
  if distances == 0
    error('error: distances = 0 in LoadDistances\n');
  end
  progress = sum(sum(distances(:,:,1) >= 0));
  if progress ~= best_progress
    message = sprintf('error: in LoadDistances, progress = %li != %li\n', progress, best_progress);
    error(message);
  end
  disp(sprintf('best progress read = %li\n', best_progress));
  save_counter = best_index + 1;
  return;
end

% If we did not find a progress file, then we need to load up 
% each matrix and count its progress.
for i = 0:(robin_length-1)
  distances1 = read_distances(base_path, i);
  % Note that if the matrix is zero, we get progress = -1.
  if (distances1 == 0)
      progress = -1;
  else
      progress = sum(sum(distances1(:,:,1) >= 0));
  end
  if progress > best_progress
    best_progress = progress;
    best_index = i;
    distances = distances1;
  end
end

% If we still did not find a progress file, error.
if (best_index < 0)
    distances = -1;
    save_counter = -1;
    return;
end

disp(sprintf('best progress computed = %li\n', best_progress));
save_counter = best_index + 1;
return;
