function result = v_randperm(n)

% v_randperm(n) is a deterministic substitute of randperm(n), that
% assumes n <= 1000 and always returns the same result for same n. This way
% we call demo_2a and get always the same result, so that we
% can compare different implementations of the same function and
% check if they behave exactly the same

if n > 1000
    disp(['n = ', num2str(n)]);
    error('v_randperm:n_over_1000', 'v_randperm called witn n over 1000');
end

precomputed = [
         636
         693
         353
         775
         444
         683
         976
         788
         153
         389
         394
         350
         878
           5
         837
         491
         594
         611
         216
         545
         916
         914
          27
         476
         771
         917
         674
         455
         183
         614
         659
         841
         644
         882
         705
         855
         737
         698
         655
         521
         843
         178
         710
         219
         931
         236
         892
         603
         998
         844
         226
         719
         385
         943
         185
         573
         366
           2
         450
         807
          96
         996
          60
         293
         109
         729
         161
         124
         725
         114
         948
         543
         572
         932
         147
         191
         945
         629
         489
         167
         648
         397
         667
         101
         944
         487
         290
         372
         697
         774
         850
         885
         117
         989
         641
         285
         181
         220
         547
         291
         245
           9
         713
         199
         104
         267
         871
         938
         957
         701
         845
         870
         684
         872
          89
         899
         426
         814
         677
         511
         848
         148
          23
         630
         523
          45
         106
         549
         346
         362
          94
         365
         796
         462
         618
         480
         577
         749
          56
         961
         451
         650
         524
          90
          21
         513
         485
          28
         779
          51
         248
         560
         570
         417
         534
         214
         925
         859
         322
         319
         174
         433
         432
         922
         595
         454
         507
         434
         551
         517
         879
         883
         816
         939
         884
         695
         529
         327
         110
         138
         404
         303
         193
         477
         829
         902
         378
         623
         144
         111
         600
         592
         858
         680
         830
         591
         987
         447
         284
         266
         751
         501
         696
         123
         753
         550
          39
         782
         418
         446
         172
         731
         540
         770
         831
         481
         344
          22
         822
         776
         364
         801
         361
         906
         860
          68
         146
         812
         299
         377
         735
         340
          64
          10
         950
         657
         834
         723
         726
         442
         145
         576
         700
         689
         761
         250
         395
         578
         190
         809
          26
         978
         588
         887
         205
         313
          43
         223
         544
         296
         416
         457
         566
         331
         869
         969
         649
          62
         239
         252
         438
         675
         140
         201
         162
         367
         495
         356
         682
         908
          49
          92
         375
         207
          47
         261
         852
         651
         270
         390
         137
         765
         414
         379
         703
         756
         694
         558
          37
        1000
          63
         799
         767
           7
         391
         711
         275
         262
         639
         520
         321
         997
          69
         192
         359
         744
         108
         400
         991
         846
         238
         903
          57
         465
         541
         143
         131
         564
         863
         894
         645
         184
         962
         797
         763
         494
         676
         741
         790
         200
         429
         483
         196
         740
         179
         188
         334
         759
         808
         430
         215
         257
         130
         160
         424
         539
         316
         283
         519
         835
         638
         565
         332
         873
         877
         233
         589
         132
         469
         530
         956
         631
          35
         186
         940
         757
         642
         141
         119
         666
          84
         246
         612
         522
         875
         525
         663
         187
         802
         164
         626
         113
         387
         202
         382
         407
         787
         118
         493
         699
         458
         764
         357
         661
         129
         234
         622
         396
         952
         721
         212
         762
         769
         598
         821
         665
         452
         620
         243
         910
         717
         752
         242
         425
         967
          14
          80
         605
         625
         126
         208
          95
         374
         934
         484
         528
         325
         597
         915
         789
          40
         437
         392
         225
         748
         180
          59
         702
         488
         792
         369
         399
         983
         328
         773
          17
         990
         535
         415
         730
         388
         467
         241
         317
         412
         840
         619
         864
         865
         895
         295
         206
         497
         606
         105
         218
          77
         715
         532
         289
         670
         853
         538
         681
         170
         499
         478
         312
         253
         928
          18
         933
         305
         518
          29
         256
         918
         408
         168
          88
         635
         747
         423
         727
          11
         281
         231
         176
         672
         371
         658
         733
         370
         960
         311
         963
         954
         496
         466
         849
          46
         235
         913
         953
         120
         318
         354
         336
         173
         500
         427
          82
          55
         337
          53
         468
         574
          72
         616
         900
         919
         959
         159
         690
         473
         403
         988
         277
         810
         596
          24
         149
         586
         889
         304
         258
          83
          86
         486
         820
         936
         912
         898
         593
         986
         861
         490
         155
          93
         758
         994
         881
         838
         685
         742
          42
          98
         632
         553
         671
         259
         901
         298
          66
         314
         360
         750
         463
          13
         968
         502
         505
         154
         420
         781
         279
         926
          54
          70
         512
          48
         866
         475
           1
          65
         949
         955
         134
         503
         381
         171
         722
         280
         654
         628
         287
         839
         973
         409
         958
         222
         556
         240
         970
         615
         263
         333
         479
         817
         330
         133
         720
         607
         561
         806
         348
         923
         273
         930
         439
         617
         971
         449
         562
         911
          76
         272
         355
         343
         338
         823
          41
         679
         276
         335
         780
         818
         526
         441
         643
         349
         122
         766
         413
         854
         492
         142
          20
          78
         660
         575
         177
         213
         581
         410
         286
         470
          44
         504
         613
         229
         510
         249
         813
         554
         647
         308
          73
         112
         324
         380
          74
         811
         590
         946
         601
         182
         461
         115
         309
         464
         941
         135
         754
         232
         459
         402
         150
         156
         421
         851
          16
         836
         209
         692
         688
         393
         827
         995
         568
         571
         107
         876
         783
         980
         569
         795
         653
         847
         793
         966
         867
         868
         244
         265
          36
         627
         194
         896
         151
         102
         712
         965
         230
         874
         301
         251
           4
         743
         981
         738
         306
         268
         633
         515
         608
           6
         175
         964
         678
         924
         805
         329
         247
         886
           8
          33
         368
         315
         157
         269
         411
         825
         888
         826
         506
         772
         559
         832
         204
         662
         217
         786
         734
         819
          99
          52
         921
         436
         652
         198
         552
         453
         527
         197
         637
         985
         929
          50
         443
          91
         791
         165
         992
         777
         798
          38
         351
         195
         993
          97
         445
         800
         736
         125
         431
         691
         907
         732
         563
         909
         406
         718
         498
         288
         746
         587
          15
          87
         624
         210
         745
         828
         709
         778
         785
         401
         158
         211
         384
         386
         724
         755
         640
         824
         599
         326
         255
         508
          25
         169
         271
         656
         294
          85
         456
         302
         815
         704
         116
         422
         254
         580
          58
          31
         880
          67
         472
           3
         166
         460
         278
         471
         516
          12
         555
         533
         582
         579
         292
         310
         342
         300
          30
         604
          19
         398
          34
          61
         585
         862
         264
         189
         664
         686
         127
         121
         856
         982
         405
         203
         542
         352
         687
          71
         972
         760
         227
         999
         621
         833
         419
         435
         345
         947
         602
         975
         548
         536
         567
         669
         139
         260
         610
         224
         927
         977
         803
         897
         376
         714
         323
         383
         152
         557
         905
         282
         937
         584
         890
         339
         728
         514
         794
          75
         274
         739
         707
         920
         221
         474
         904
         646
         583
         768
         857
         347
         373
         428
         136
         951
          81
         448
         358
         531
         228
         363
          79
         942
         537
         307
         320
         706
         634
         668
         984
         804
         893
         979
         708
         440
         716
         297
         842
         482
         935
         891
         237
         128
         673
         163
         341
         100
         974
         609
          32
         509
         546
         103
         784
     ]';
     
indices = (precomputed <= n);
result = precomputed(indices);